Assets class
This file is automatically generated. DO NOT EDIT, all your changes would be lost.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- assetsBackProjection8 → const String
- assetsBackProjection16 → const String
- assetsBackProjection32 → const String
- assetsBackProjection64 → const String
- assetsGaussNewton8 → const String
- assetsGaussNewton16 → const String
- assetsGaussNewton32 → const String
- assetsGaussNewton64 → const String
- assetsGreit8 → const String
- assetsGreit16 → const String
- assetsGreit32 → const String
- assetsGreit64 → const String
- assetsOnline → const String
- assetsSimdata8 → const String
- assetsSimdata16 → const String
- assetsSimdata32 → const String
- assetsSimdata64 → const String